@@ -7,8 +7,10 @@ use warnings;
 use English qw< -no_match_vars >;
 use Data::Dumper;
 use Scalar::Util qw< blessed >;
+our $VERSION = '0.722';
 
-use Log::Log4perl::Tiny qw< :easy :dead_if_first get_logger LOGLEVEL >;
+use Log::Log4perl::Tiny
+  qw< :easy :dead_if_first get_logger LOGLEVEL LEVELID_FOR >;
 use Data::Tubes qw< tube >;
 use Data::Tubes::Util
   qw< normalize_args traverse args_array_with_options >;
@@ -28,17 +30,17 @@ sub dispatch {
    LOGDIE "$name: required dispatch key or selector"
      unless defined $selector;
 
-   my $handler_for = {%{$args{handlers}||{}}};   # our cache
-   my $factory     = $args{factory};
+   my $handler_for = {%{$args{handlers} || {}}};    # our cache
+   my $factory = $args{factory};
    if (!defined($factory)) {
-      $factory     = sub {
+      $factory = sub {
          my ($key, $record) = @_;
          die {
             message => "$name: unhandled selection key '$key'",
             record  => $record,
          };
       };
-   } ## end if (!defined($factory)...)
+   } ## end if (!defined($factory))
    LOGDIE "$name: required factory or handlers"
      unless defined $factory;
 
@@ -65,7 +67,7 @@ sub dispatch {
 sub logger {
    my %args = normalize_args(@_, {name => 'log pipe', loglevel => $INFO});
    identify(\%args);
-   my $loglevel = $args{loglevel};
+   my $loglevel = LEVELID_FOR($args{loglevel});
    my $mangler  = $args{target};
    if (!defined $mangler) {
       $mangler = sub { return shift; }
@@ -100,7 +102,8 @@ sub sequence {
             return shift @record;
          }
       );
-   } unless @$tubes;
+     }
+     unless @$tubes;
 
    # auto-generate tubes if you get definitions
    my @tubes = map {
